#!/bin/ksh

# Make sure running as root user

if [ -f /usr/ucb/whoami ] ; then
  user_name=`/usr/ucb/whoami`
else
  user_name=`whoami`
fi

if [[ $user_name != "root" ]]
then
   echo "Error: This script should be run by root user only"
   echo ""
   kill $$
fi

# Set backup file name extension
bak=preIY32535

# Get locations of tar file and temp expansion directory

echo "Enter location of the IY32535.tar file"
echo "Example:  /temp"
read tarloc

tarloc=$tarloc/IY32535.tar

if [ ! -n "$tarloc" ] ; then
  echo "You need to enter the location of the tar file. Exiting.."
  exit 1
fi
if [ ! -e "$tarloc" ] ; then
   echo "$tarloc does not exist"
   exit 1
fi

echo "Enter directory for content of tar file to be temporarily stored"
read jarloc


if [ ! -n "$jarloc" ] ; then
  echo "You need to enter a temporary directory name. Exiting.."
  exit 1
fi
if [ ! -e "$jarloc" ] ; then                        /
   echo "$jarloc does not exist"
   exit 1
fi


#
# Set product root for current OS
#



if [ -d /usr/TivTSM ] ; then
   WESM_ROOT=/usr/TivTSM
   echo "Detected AIX system"

   WAS_ROOT=`find /usr -name installedApps -print`
   if [ -d $WAS_ROOT ] ; then
      echo "WAS installed App directory detected at: "$WAS_ROOT
   fi

   if [ -e /usr/TivTSM/radius/bin/start_radius_db2.ksh ] ; then
     RAD_LOC=aix4db2_7
     echo "Detected DB2"
   else
     if [ -e /usr/TivTSM/radius/bin/start_radius.ksh ] ; then
       RAD_LOC=aix4ora8
       echo "Detected Oracle" 
     fi
   fi
else
   if [ -d /opt/TivTSM ] ; then
      WESM_ROOT=/opt/TivTSM
      echo "Detected Solaris system"

      WAS_ROOT=`find /opt -name installedApps -print`
      if [ -d $WAS_ROOT ] ; then
         echo "WAS installed App directory detected at: "$WAS_ROOT
      fi

      if [ -e /opt/TivTSM/radius/bin/start_radius_db2.ksh ] ; then
        RAD_LOC=sunos5db2_7
        echo "Detected DB2"
      else
        if [ -e /opt/TivTSM/radius/bin/start_radius.ksh ] ; then
          RAD_LOC=sunos5ora8
          echo "Detected Oracle"
        fi
      fi
   else
      echo "Could not find product root, exiting"
      exit
   fi
fi

# Expand tar file
cp $tarloc $jarloc
cd $jarloc
tar -xf $tarloc


# replace RADIUS executable files (defect 26435)

# Stop RADIUS servers
if [ -d $WESM_ROOT/radius ] ; then
   echo "Stopping RADIUS servers"
   PID_FILE=`find $WESM_ROOT/radius -name *.pid -print`
   for k in $PID_FILE ; do
      PID=`cat $k`
      echo "   kill $PID"
      kill $PID
   done

   # Replace RADIUS executable files
   for j in "radius-auth" "radius-acct" ; do
   	REPLACE=`find $WESM_ROOT -name $j -print`
   	for k in $REPLACE ; do
   		echo "Replacing $k"
                if [ ! -e ${k}.$bak ] ; then 
                  echo "  cp $k ${k}.$bak"
                  cp $k ${k}.$bak
                fi
   		echo "  cp $jarloc/$RAD_LOC/radiusNG $k"
   		cp $jarloc/$RAD_LOC/radiusNG $k
    	done
   done
  
fi

# Replace localeStyle.jsp (defect 26290.1)

if [ -d $WAS_ROOT ] ; then
   echo "Replacing localeStyle.jsp files"
   for j in "localeStyle.jsp" ; do
         REPLACE=`find $WAS_ROOT -name $j -print`
         for k in $REPLACE ; do 
            echo "  Replacing $k"
            if [ ! -e ${k}.$bak ] ; then
              echo "  cp $k ${k}.$bak"
              cp $k ${k}.$bak
            fi
            echo "    cp $jarloc/$j $k"
            cp $jarloc/$j $k
            # touch all jsp files in that directory
            # some may include this localeStyle.jsp so need to
            # be re-compiled by WAS
            echo "  Touching JSP files so they will re-compile"
            JSP_DIR=${k%/*}
            echo "     touch $JSP_DIR/*.jsp"
            touch $JSP_DIR/*.jsp
         done
   done
fi

# Replace Provisioning Server jar file
 #Stop Provisiong Server first
 if [ -e $WESM_ROOT/provisioning/bin/StopProvServer.ksh ] ; then
   echo "Stopping Provisioning Server"
   $WESM_ROOT/provisioning/bin/StopProvServer.ksh

   echo "Replacing Provisioning Server jar files"
   for j in "HSMProvServer*.jar" ; do
      REPLACE=`find $WESM_ROOT/classes -name $j -print`
      for k in $REPLACE ; do
         echo "  Replacing $k"
         if [ ! -e ${k}.$bak ] ; then
           echo "  cp $k ${k}.$bak"
           cp $k ${k}.$bak
         fi
         echo "    cp $jarloc/${k##*/} $k"
         cp $jarloc/${k##*/} $k
      done
   done
 fi

# Replace ldap jar file
 #Stop ldap Gateway
 if [ -e $WESM_ROOT/ldap/bin/stop-LDAPGateway.ksh ] ; then
   echo "Stopping LDAP Provisioning Agent"
   $WESM_ROOT/ldap/bin/stop-LDAPGateway.ksh

   echo "Replacing LDAP jar files"
   for j in "ldap_integ.jar" ; do
      REPLACE=`find $WESM_ROOT/ldap -name $j -print`
      for k in $REPLACE ; do
         echo "  Replacing $k"
         if [ ! -e ${k}.$bak ] ; then
           echo "  cp $k ${k}.$bak"
           cp $k ${k}.$bak
         fi
         echo "    cp $jarloc/${k##*/} $k"
         cp $jarloc/${k##*/} $k
      done
   done
 fi


echo "*** Installation complete ***"


